function [Xn] = notrend(I,param,piece);
//  Removes mean values and / or trends.
//  
//  Calling sequence
//  [Xn] = notrend(I,param,piece);
//  
//  Parameters
//  I : matrix [m,N] : input matrix
//  param :integer 1,2 : mean value, trend
//  piece : integer : length of trend
//  Xn : matrix [m,N] : matrix relieved of mean value / trend
//
//  Description
//  Depending up parameter value removes mean value or trend. Expects m rows of datasets.
//  If the input matrix is of wrong size, transposition is applied. 
//
//  Examples
//  x = [0 1 2 3 4 3 2 1];
//  X = [x x x x x x x x x x x x x x x x x x x];
//  X1 = [X X X X X];
//  Y = (X1.^2)/2 - 2;
//  for i = 1:length(Y)
//    o(i) = abs(((i/2-length(Y)+1)/40)) + 0.8*sin(Y(i)/2) + sin(i);
//  end
//  o = (o-mean(o));
//  a = [o; -o]';
//  u = [notrend(a,2,760)]';
//  plot(a);plot(u,'g');
//
//
//  See also
//  rsmp
//  alias_k
//  ampl_k
//  pp_k
//  pz_k
//  d_k
//  h_k
//  
//  CODE    
    size_I = size(I);
    if (size_I(1)>size_I(2))
      I = I';
    end
    size_I = size(I);
    r = size_I(1);
    s = size_I(2);
    for i = 1:r
      x = I(i,1:s);
  x = x';
  L = length(x);
  if param == 1 then
    xn = x-mean(x);
    xn = xn';
  end
  if param == 2 then
    piece = unique([0;double(piece(:));L-1]);	
    p_length = length(piece)-1;
    a  = [zeros(L,p_length) ones(L,1)];
  for kb = 1:p_length
    M = L - piece(kb);
    a((1:M)+piece(kb),kb) = (1:M)'/M;
  end
  xn = x - a*(a\x);
  xn = xn';
end
Xn(i,1:s) = xn;
end
endfunction