function [tzab, XZab,t,I] = rsmp(I,m,c)
//  Resamples the input vector (matrix).  
//  
//  Calling sequence
//  [tzab, XZab,t,I] = rsmp(I,m,c)
//
//  Parameters
//  I: matrix [m,N1] : input matrix 
//  m: integer : upsampling rate
//  c: integer : downsampling rate
//  tzab: vector [1,N2] : output-matrix time domain
//  XZab: matrix [m,N2] : output matrix
//  t: vector [1,N1] : original-matrix time domain
//  I : matrix [m,N1] : original matrix
//
//  Description
//  Resamples the input vector I at (m/c)-times the original sample rate. 
//  Output vector XZab has the same time duration, the corresponding time vector
//  is returned in tzab. If I is a matrix, then each row of I is resampled.
//
//  First, the input vector is upsampled m-times using linear interplolation.
//  After upsampling, the vector is downsampled c-times by choosing every c-th sample.
// 
//  Examples
//  X=[2 4 5 9 23 1 35 6 9 23 1 16.5 1 5 -1 -3 -4 -1 10 16 12 -3 -22 6 -8 10 4 0 6 -2];
//  f_vz = 10;
//  m=4;c=5;
//  [tnew,Xnew,t,X] = rsmp(X,m,c);
//  plot(t,X);plot(tnew,Xnew,'r');    // old signal, new signal without anti-aliasing filter
//  f_new = (m/c)*f_vz;
//  [tn,s_old,s_new, f,freq_old,freq_new] = alias_k(X,f_vz,f_new);
//  [tnn,s_newn,tx,s_new] = rsmp(s_new,m,c);
//  plot(tnn,s_newn,'k');          // new signal with antialiasing filter
//  
//
//  See also
//  notrend
//  ampl_k
//  alias_k
//  pp_k
//  pz_k
//  d_k
//  h_k

// CODE

S = size(I);
for q = 1: S(1)
X = I(q,:); 
X = X';
  a=0;k=0;

Xd=[0;X];
Xh=[X;0];
rozdiel=Xh-Xd;
roz=rozdiel(2:length(rozdiel)-1);
rozvz=roz./m;
for i= 1:length(roz)
  for j=1:m
    a=a+1;
    Xn(a)=X(i)+(j-1)*rozvz(i);
     if((a/c)==int(a/c))
       k=k+1;
       if (k ==1)
         Xzab(k) = X(k);
         end
       Xzab(k)=Xn(a);
      end
  end
end
t = 1:length(X);
tzab = 1:c/m:length(X);
tzab = tzab(2:length(tzab));
tzab = tzab-(1/m);
X = X';
XZab(q,:) = Xzab';
end;

endfunction
//  ********************************