function [K,R] = gl2kr(A,G,C,L0)
// [K,R] = gl2kr(A,G,C,L0)
// Solves the Kalman gain (K) and the innovation covariance (R)
// Model is in an innovation form as follows:
//                 x_{k+1} = A x_k + K e_k
//                   y_k   = C x_k + e_k
//                cov(e_k) = R



if isempty(G) | isempty(L0) then
  K = [];
  R = [];
else // Solve the Riccati equation
  [P,flag] = myriccati(A,G,C,L0);
  if flag ==1 then 
    disp("Warning: Non positive real covariance model => K = R = []");
    K = [];
    R = [];
  else
    R = L0 - C*P*C';  //Page 63 
    K = (G - A*P*C')*inv(R);
   end;
end;

endfunction
