function [P,flag] = myriccati(A,G,C,L0)
// [P,flag] = myriccati(A,G,C,L0)
//    a) Solves the Forward Riccati equation: (page 62: generalized eigenvalue decomposition)
//       P = A P A' + (G - A P C') (L0 - C P C')^(-1) (G - A P C')' 
//       flag = 1 when the covariance sequence is not positive real
//    b) Solves the Backward Riccati equation:
//       [N,flag] = myriccati(A',C',G',L0')
//       N = A' N A + (C' - A' N G) (L0 - G' N G)^(-1) (C' - A' N G)'




if isempty(L0) | isempty(G) then
  P = [];
  flag = 0;
else
  [n,n]=size(A); 			// Dimensions
  L0i=inv(L0); 				//Compute the inverse once

  // Set up the matrices for the eigenvalue decomposition
  AA = [A'-C'*L0i*G' zeros(n,n);-G*L0i*G' eye(n,n)];
  BB = [eye(n,n) -C'*L0i*C;zeros(n,n) A-G*L0i*C];

  // Compute the eigenvalue decomposition: Via schur decomposition (in Matlab eig, or more complicated via matlab QZ)
  //Scilab schur is different than matlab schur!!!!
  // AA(1,1)=AA(1,1)+0*%i; //ensures complex schur decomposition
  [v,d] = spec(inv(BB)*AA); //WORKS correctly only for regular matrix !!
  ew=diag(d);


  // If there's an eigenvalue on the unit circle => no solution
  flag = 0;
  if prod(abs(abs(ew)-ones(2*n,1)) > 1e-9) < 1 then flag = 1;end

  // Sort the eigenvalues
  [dum,I]=gsort(abs(ew),'g','i') ;

  //Compute P
  P=real(v(n+1:2*n,I(1:n))/v(1:n,I(1:n)));
end
endfunction
