function x = tls(A, b)    
// Total-Least Squares solution to a set of linear equations (A + E)x = b + f where E and f are white noise.
//
// Calling Sequence
// [x] = tls(A, b) // 
// Parameters
// A: A
// b: b
// x: Total-Least Squares solution to a set of linear equations (A + E)x = b + f
// 
// Description
// Total-Least Squares solution to a set of linear 
// equations (A + E)x = b + f where E and f are white noise. 
// This function is used to estimate parameters of so called
// Errors-In-Variables systems (both measured input (A + E) and
// output b + f data are corrupted by white noise).
// 
// Examples
// A=[1 3 2 4; 3 2 3 2; 3 4 3 1; -9 -1 2 -1];
// b=[30 23 25 -12]';
// x = tls(A, b);
// A*x
//
// See Also
//  arx
//  rtls
// 
// Authors
// 
// Bibliography
//     G. Golub, C. F. Von Loan: Matrix Computations (J. Hopkins University Press, Baltimore, 1996)
//

//---------------Total-Least Squares algorithm---------------
n = size(A,2);
Data = [A b];
[U S V] = svd(Data);
V12 = V(1:n,1+n:$);
V22 = V(1+n:$,1+n:$); // bottom-right block of V
if det(V22) == 0
    disp('The problem has no solution. TLS solution may be singular.');
    return;
end
x = -V12*pinv(V22);
endfunction
